/*
 * checkerberry test center - https://www.checkerberry.de
 *
 * Copyright (c) 2010 ConceptPeople consulting gmbh
 *
 * Lizenziert unter der EUPL, Version 1.1 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/software/page/eupl5
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.conceptpeople.checkerberry.db.example.dao;

import java.util.List;

import org.hibernate.criterion.DetachedCriteria;
import org.hibernate.criterion.Restrictions;
import org.springframework.orm.hibernate3.support.HibernateDaoSupport;

import de.conceptpeople.checkerberry.db.example.entities.User;

/**
 * DAO zum Zugriff auf die User-Entities. Dieses DAO wird exemplarisch getestet.
 */
public class UserDao extends HibernateDaoSupport {

    /**
     * Liefert den eindeutigen User zurück.
     * 
     * @param name
     *            Vorname.
     * @param surname
     *            Nachname.
     * @return eindeutiger User oder <code>null</code>, wenn es keinen
     *         entsprechenden User gibt.
     */
    @SuppressWarnings("unchecked")
    public User getUser(String name, String surname) {
        DetachedCriteria criteria = DetachedCriteria.forClass(User.class);
        criteria.add(Restrictions.eq("name", name));
        criteria.add(Restrictions.eq("surname", surname));

        List<User> users = getHibernateTemplate().findByCriteria(criteria);
        return users.isEmpty() ? null : users.get(0);
    }

    /**
     * Speichert den angegebenen User oder aktualisiert den Eintrag, wenn
     * bereits vorhanden.
     * 
     * @param user
     *            zu speichernder User.
     */
    public void saveOrUpdate(User user) {
        getHibernateTemplate().saveOrUpdate(user);
    }

    /**
     * Speichert den angegebenen User als neuen Datensatz in der Tabelle.
     * 
     * @param user
     *            zu speichernder User.
     */
    public void save(User user) {
        getHibernateTemplate().save(user);
    }

    /**
     * Löscht den angegebenen User.
     * 
     * @param user
     *            zu Löschender User.
     */
    public void delete(User user) {
        getHibernateTemplate().delete(user);
    }

    /**
     * Liefert alle User der Tabelle zurück.
     * 
     * @return Liste der User.
     */
    @SuppressWarnings("unchecked")
    public List<User> getUsers() {
        return getHibernateTemplate().loadAll(User.class);
    }
}
