/*
 * checkerberry test center - https://www.checkerberry.de
 *
 * Copyright (c) 2010 ConceptPeople consulting gmbh
 *
 * Lizenziert unter der EUPL, Version 1.1 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/software/page/eupl5
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.conceptpeople.checkerberry.db.example.generator;

import java.io.Serializable;

import org.hibernate.engine.SessionImplementor;
import org.hibernate.id.IdentifierGenerator;

/**
 * Ein einfacher Id-Generator für Demo-Zwecke.
 */
public class TimeIdGenerator implements IdentifierGenerator {

    /** Initialer Offset für die Ermittlung der Id. */
    private static final int INITIAL_OFFSET = 1000;
    /** Modulo zum Abrunden der aktuellen Zeit in Millisekunden. */
    private static final int MODULO_TIME = 10000;
    
    private static int lastUsed = INITIAL_OFFSET;

    /**
     * {@inheritDoc}
     */
    @Override
    public Serializable generate(SessionImplementor session, Object object) {

        int nextId = INITIAL_OFFSET + (int) (System.currentTimeMillis() % MODULO_TIME);
        while (nextId <= lastUsed) {
            nextId++;
        }
        lastUsed = nextId;

        return Integer.valueOf(nextId);
    }
}
