/*
 * checkerberry test center - https://www.checkerberry.de
 *
 * Copyright (c) 2010 ConceptPeople consulting gmbh
 *
 * Lizenziert unter der EUPL, Version 1.1 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/software/page/eupl5
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.conceptpeople.checkerberry.db.example;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

import de.conceptpeople.checkerberry.db.bridge.configuration.functions.TestdataFunction;
import de.conceptpeople.checkerberry.db.bridge.context.ExecutionContext;

/**
 * Beispielfunktion zur Bestimmung des Gewichts der Simpsons.
 */
public class WeighingFunction implements TestdataFunction {

    private Map<String, String> simpsonToWeight = new HashMap<String, String>();

    /**
     * Erzeugt eine neue Funktion.
     */
    public WeighingFunction() {
        // Statisches Mapping von Name zu Gewicht. Für Demo-Zwecke sollte das
        // ausreichend sein...
        simpsonToWeight.put("Homer", "80.0");
        simpsonToWeight.put("Marge", "60.0");
        simpsonToWeight.put("Bart", "20.0");
        simpsonToWeight.put("Lisa", "15.0");
        simpsonToWeight.put("Maggie", "9.0");
    }

    /**
     * Erwartet als Parameter einen String mit dem Vornamen des Mitglieds der
     * Simpson-Familie.
     * 
     * @param context
     *            der aktuelle Ausführungskomntext. Kann verwendet werden um
     *            beispielsweise Parameter aufzulösen.
     * @param arguments
     *            Liste der Argumente des Funktionsaufrufes. Die Argumente sind
     *            vor aufruf dieser Methode vollständig aufgelöst worden und
     *            enthalten keinerlei Funktionsaufrufe oder Parameter mehr.
     * @param functionName
     *            Name, unter dem die Funktion aufgerufen wurden oder null,
     *            falls kein solvher verfügbar ist.
     * 
     * @return Gewicht der Person.
     */
    @Override
    public String evaluate(ExecutionContext context, List<String> arguments, String functionName) {

        if (arguments == null || arguments.size() != 1) {
            throw new IllegalArgumentException("Ungültige Parameter für Funktion '" + functionName + "': "
                    + arguments);
        }

        String name = arguments.get(0);
        String weight = simpsonToWeight.get(name);

        if (weight == null) {
            throw new IllegalArgumentException("Ungültiger Name für Funktion '" + functionName + "': " + name);
        }

        return weight;
    }
}
