/*
 * checkerberry test center - https://www.checkerberry.de
 *
 * Copyright (c) 2010 ConceptPeople consulting gmbh
 *
 * Lizenziert unter der EUPL, Version 1.1 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/software/page/eupl5
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.conceptpeople.checkerberry.db.example.config;

import java.io.File;

import org.junit.Test;

import de.conceptpeople.checkerberry.db.bridge.configuration.DbConfiguration;
import de.conceptpeople.checkerberry.db.bridge.configuration.TestdataNameResolver;
import de.conceptpeople.checkerberry.db.example.AbstractExampleTestCase;

/**
 * Beispieltest für speziellere Konfigurationseinstellungen.
 * <p/>
 * Zum einen wird die Tabelle USERDISHREL auf die globale Ignore-Liste gesetzt.
 * Diese Tabelle wird durch checkerberry dann vollständig ignoriert. Dies kann
 * z.B. für temporäre Tabellen o.ä. sinnvoll sein. Bei der Angabe kann man auch
 * die Wildcards "?" (ein beliebiges Zeichen) und "*" (beliebig viele beliebige
 * Zeichen) verwenden.
 * <p/>
 * Zum anderen wird die Syntax zum Auffinden der Testdateien geändert. Wenn man
 * es noch spezieller möchte, kann man auch einen eigenen
 * {@link TestdataNameResolver} schreiben und unter
 * {@link DbConfiguration#setTestdataNameResolver(TestdataNameResolver)}
 * einhängen.
 */
public class DbExampleConfigIntegrationTest extends AbstractExampleTestCase {

    /**
     * Demonstriert das Laden und Prüfen der Testdaten im neuen Format.
     *
     * @throws Exception
     *             wenn ein Fehler aufgetreten ist.
     */
    @Test
    public void testLoadAndCheckData() throws Exception {

        // Die Tabelle USERDISHREL wird global ignoriert und ist nicht im Report
        // enthalten.
        File diffReportFile = File.createTempFile("-diffReport", ".html");
        // Diese Zeile auskommentieren, um einen Blick in die Datei zu werfen.
        diffReportFile.deleteOnExit();

        getTestHandler().createDiffReport(diffReportFile.getAbsolutePath());

        // Die Tabelle USERDISHREL wird global ignoriert und ist nicht im Dump
        // enthalten.
        File dumpFile = File.createTempFile("-dump", ".xml");
        // Diese Zeile auskommentieren, um einen Blick in die Datei zu werfen.
        dumpFile.deleteOnExit();
        getTestHandler().dumpDatabase(dumpFile.getAbsolutePath());

        getTestHandler().assertEqualsExpected();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    protected String getBridgeContainerBeanName() {

        // Verwendet den Bridge-Container mit den angepassten Konfigurationen.
        return "bridgeContainerWithCustomConfig";
    }
}
