/*
 * checkerberry test center - https://www.checkerberry.de
 *
 * Copyright (c) 2010 ConceptPeople consulting gmbh
 *
 * Lizenziert unter der EUPL, Version 1.1 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/software/page/eupl5
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.conceptpeople.checkerberry.db.example.dtd;

import java.io.BufferedReader;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.IOException;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.junit.Assert;
import org.junit.Test;

import de.conceptpeople.checkerberry.common.util.FileUtility;
import de.conceptpeople.checkerberry.db.example.AbstractExampleTestCase;

/**
 * Beispieltest für die Erzeugung einer neuen DTD.
 */
public class DbExampleDtdIntegrationTest extends AbstractExampleTestCase {
    private static final Logger LOG = LoggerFactory.getLogger(DbExampleDtdIntegrationTest.class);

    /**
     * Zeigt die Erzeugung einer DTD anhand der aktuellen Datenbank.
     *
     * @throws Exception
     *             wenn ein Fehler aufgetreten ist.
     */
    @Test
    public void testCreateDtd() throws Exception {
        File tmpDtdFile = File.createTempFile("-example-db", ".dtd");
        // Wenn Sie einen Blick in die Datei werfen wollen, müssen sie die
        // nächste Zeile auskommentieren.
        tmpDtdFile.deleteOnExit();

        // Der Aufruf ermittelt alle Tabellen und Spalten in der Datenbank und
        // erstellt anhand der Abhängigkeiten eine neue DTD.
        // Zusätzlich werden die Pseudo-Tabellen INCLUDE und EMPTY_TABLE
        // eingefügt.
        getTestHandler().createDtd(tmpDtdFile.getCanonicalPath());

        // DTD-Inhalt loggen.
        logFileContent(tmpDtdFile);
    }

    /**
     * Loggt den Inhalt der angegebenen Datei.
     *
     * @param file
     *            zu loggende Datei.
     */
    private void logFileContent(File file) {

        BufferedReader reader = null;
        try {
            reader = new BufferedReader(new FileReader(file));
            String line = null;
            while ((line = reader.readLine()) != null) {
                LOG.info(line);
            }
        } catch (FileNotFoundException e) {
            Assert.fail("Unexpected exception: " + e);
        } catch (IOException e) {
            Assert.fail("Unexpected exception: " + e);
        } finally {
            FileUtility.close(reader);
        }
    }
}
