/*
 * checkerberry test center - https://www.checkerberry.de
 *
 * Copyright (c) 2010 ConceptPeople consulting gmbh
 *
 * Lizenziert unter der EUPL, Version 1.1 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/software/page/eupl5
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.conceptpeople.checkerberry.db.example.empty;

import org.junit.Test;

import de.conceptpeople.checkerberry.db.bridge.configuration.DbConfiguration;
import de.conceptpeople.checkerberry.db.bridge.configuration.DbConfigurationCallback;
import de.conceptpeople.checkerberry.db.core.test.ClearTables;
import de.conceptpeople.checkerberry.db.example.AbstractExampleDaoTestCase;

/**
 * Beispieltest für die Verwendung des EMPTY_TABLE-Tags. Testdaten können über
 * das Tag EMPTY_TABLE leere Tabellen definieren. Sollte in der entsprechenden
 * Datenbank eine Tabelle mit dem Namen EMPTY_TABLE existieren, würde sich ein
 * Konflikt ergeben. Aus diesem Grund kann in der Klasse
 * {@link DbConfigurationCallback} der Name der Tabelle geändert werden (
 * {@link DbConfiguration#setEmptyTableName(String)}).
 * <p/>
 * Das Tag EMPTY_TABLE kann sowohl in den initialen wie auch in den erwarteten
 * Testdaten verwendet werden. Beim Einspielen der initialen Daten wird geprüft,
 * ob die entsprechenden Tabellen wirklich leer sind. Auf diese Art und Weise
 * kann verhindert werden, dass versehentlich Datensätze für diese Tabelle über
 * inkludierte Dateien eingelesen werden. In den erwarteten Testdaten wird
 * geprüft, ob die entsprechende Tabelle in der Datenbank leer ist.
 */
public class DbExampleEmptyTableIntegrationTest extends AbstractExampleDaoTestCase {

    /**
     * Lädt initiale Testdaten, in denen die Tabelle USERS explizit als leer
     * markiert ist.
     */
    @Test
    public void testLoadEmptyTable() {

        assertEquals(0, getUserDao().getUsers().size());

        assertEquals(1, getDishDao().getDish().size());
        assertNotNull(getDishDao().getDish("Donuts"));
    }

    /**
     * Leert alle Tabellen und prüft, ob diese tatsächlich alle leer sind.
     *
     * @throws Exception
     *             wenn ein Fehler aufgetreten ist.
     */
    @Test
    @ClearTables
    public void testCheckEmptyTable() throws Exception {

        getTestHandler().assertEqualsExpected();
    }

}
